@@ -73,7 +73,7 @@ cpl_error_code er_frameset_to_json(const cpl_frameset * frameset,
                                    const char* json_file)
 {
     FILE             * fjson;
-    const cpl_frame  * frame;
+    cpl_size           nframes;
     cpl_size           iframe;
 
     /* Sanity checks  */ 
@@ -94,14 +94,17 @@ cpl_error_code er_frameset_to_json(const cpl_frameset * frameset,
     fprintf(fjson, "[\n");
     
     /* Loop on frames */
-    frame = cpl_frameset_get_first_const(frameset);
+    nframes = cpl_frameset_get_size(frameset);
     iframe = 0;
 
-    while (frame != NULL)
+    for(iframe = 0 ; iframe < nframes; iframe++)
     {
-        char   * filename;
-        char   * category;
+        const cpl_frame  * frame;
+        char             * filename;
+        char             * category;
         
+        /* Get this frame */
+        frame = cpl_frameset_get_position_const(frameset, iframe);
         filename = er_json_escape_string(cpl_frame_get_filename(frame));
         category = er_json_escape_string(cpl_frame_get_tag(frame));
         
@@ -119,8 +122,6 @@ cpl_error_code er_frameset_to_json(const cpl_frameset * frameset,
             fprintf(fjson, "  }\n");
         else
             fprintf(fjson, "  },\n");
-        frame = cpl_frameset_get_next_const(frameset);
-        iframe++;
         cpl_free(filename);
         cpl_free(category);
     }
@@ -150,7 +151,7 @@ cpl_error_code er_frameset_to_text(const cpl_frameset * frameset,
                                    const char* text_file)
 {
     FILE             * ftext;
-    const cpl_frame  * frame;
+    cpl_size           nframes;
     cpl_size           iframe;
 
     /* Sanity checks  */ 
@@ -168,13 +169,17 @@ cpl_error_code er_frameset_to_text(const cpl_frameset * frameset,
     }
     
     /* Loop on frames */
-    frame = cpl_frameset_get_first_const(frameset);
+    nframes = cpl_frameset_get_size(frameset);
+    iframe = 0;
 
-    while (frame != NULL)
+    for(iframe = 0 ; iframe < nframes; iframe++)
     {
-        const char   * filename;
-        const char   * category;
-        
+        const cpl_frame  * frame;
+        const char       * filename;
+        const char       * category;
+
+        /* Get this frame */
+        frame = cpl_frameset_get_position_const(frameset, iframe);
         filename = cpl_frame_get_filename(frame);
         category = cpl_frame_get_tag(frame);
         
@@ -183,7 +188,6 @@ cpl_error_code er_frameset_to_text(const cpl_frameset * frameset,
         if(iframe != cpl_frameset_get_size(frameset) - 1)
             fprintf(ftext, "\n");
         
-        frame = cpl_frameset_get_next_const(frameset);
         iframe++;
     }
     fclose(ftext);
@@ -249,14 +253,17 @@ cpl_error_code er_recipe_parameterlist_to_json(const cpl_parameterlist * plist,
 
     while (param != NULL)
     {
-        char     * description;
-        char     * name;
-        char     * display_name;
-        cpl_type   ptype;
-        int        ivalue;
-        int        bvalue;
-        double     dvalue;
-        char     * svalue;
+        char              * description;
+        char              * name;
+        char              * display_name;
+        cpl_type            valtype;
+        cpl_parameter_class partype;
+        int                 ivalue;
+        int                 bvalue;
+        double              dvalue;
+        char              * svalue;
+        int                 enum_size;
+        int                 ienum;
         
         description = er_json_escape_string(cpl_parameter_get_help(param));
         name = er_json_escape_string(cpl_parameter_get_name(param));
@@ -267,7 +274,8 @@ cpl_error_code er_recipe_parameterlist_to_json(const cpl_parameterlist * plist,
             cpl_error_reset();
             display_name = er_json_escape_string(cpl_parameter_get_name(param));
         }
-        ptype = cpl_parameter_get_type(param);
+        valtype = cpl_parameter_get_type(param);
+        partype = cpl_parameter_get_class(param);
         
         /* Open a JSON item */
         fprintf(fjson, "  {\n");
@@ -275,37 +283,117 @@ cpl_error_code er_recipe_parameterlist_to_json(const cpl_parameterlist * plist,
         /* Write this parameter fields */
         if(strlen(name) > 0)
             fprintf(fjson, "    \"name\": \"%s\",\n",name);
-        switch (ptype)
-           {
-           case CPL_TYPE_BOOL:
-               bvalue = cpl_parameter_get_bool(param);
-               if (bvalue == 0)
-                   fprintf(fjson, "    \"value\": false,\n");
-               else
-                   fprintf(fjson, "    \"value\": true,\n");
-           break;
+        /* Write value and value type */
+        switch (valtype)
+        {
+        case CPL_TYPE_BOOL:
+            bvalue = cpl_parameter_get_bool(param);
+            if (bvalue == 0)
+                fprintf(fjson, "    \"value\": false,\n");
+            else
+                fprintf(fjson, "    \"value\": true,\n");
+                fprintf(fjson, "    \"valtype\": \"bool\",\n");
+            break;
 
-           case CPL_TYPE_INT:
-               ivalue = cpl_parameter_get_int(param);
-               fprintf(fjson, "    \"value\": \"%d\",\n",ivalue);
-           break;
+        case CPL_TYPE_INT:
+            ivalue = cpl_parameter_get_int(param);
+            fprintf(fjson, "    \"value\": %d,\n",ivalue);
+            fprintf(fjson, "    \"valtype\": \"int\",\n");
+            break;
 
-           case CPL_TYPE_DOUBLE:
-               dvalue = cpl_parameter_get_double(param);
-               fprintf(fjson, "    \"value\": \"%.17g\",\n",dvalue); //IEEE 754 double
-           break;
+        case CPL_TYPE_DOUBLE:
+            dvalue = cpl_parameter_get_double(param);
+            fprintf(fjson, "    \"value\": %.17g,\n",dvalue); //IEEE 754 double
+            fprintf(fjson, "    \"valtype\": \"double\",\n");
+            break;
 
-           case CPL_TYPE_STRING:
-               svalue = er_json_escape_string(cpl_parameter_get_string(param));
-               fprintf(fjson, "    \"value\": \"%s\",\n",svalue);
-               cpl_free(svalue);
-           break;
+        case CPL_TYPE_STRING:
+            svalue = er_json_escape_string(cpl_parameter_get_string(param));
+            fprintf(fjson, "    \"value\": \"%s\",\n",svalue);
+            fprintf(fjson, "    \"valtype\": \"string\",\n");
+            cpl_free(svalue);
+            break;
 
-           default:
-               return cpl_error_set_message(cpl_func, CPL_ERROR_TYPE_MISMATCH,
+        default:
+            return cpl_error_set_message(cpl_func, CPL_ERROR_TYPE_MISMATCH,
                      "Type not supported for cpl_propertylist");
-           break;
-           }
+            break;
+        }
+
+        /* Write parameter type (called class inside CPL) */
+        switch (partype)
+        {
+        case CPL_PARAMETER_CLASS_VALUE:
+            fprintf(fjson, "    \"partype\": \"value\",\n");
+            break;
+
+        /* If a range, write the minimum and maximum.
+           Only integers and doubles are supported */
+        case CPL_PARAMETER_CLASS_RANGE:
+            fprintf(fjson, "    \"partype\": \"range\",\n");
+            switch (valtype)
+            {
+            case CPL_TYPE_INT:
+                ivalue = cpl_parameter_get_range_min_int(param);
+                fprintf(fjson, "    \"valmin\": %d,\n",ivalue);
+                ivalue = cpl_parameter_get_range_max_int(param);
+                fprintf(fjson, "    \"valmax\": %d,\n",ivalue);
+                break;
+
+            case CPL_TYPE_DOUBLE:
+                dvalue = cpl_parameter_get_range_min_double(param);
+                fprintf(fjson, "    \"valmin\": %.17g,\n",dvalue);
+                dvalue = cpl_parameter_get_range_max_double(param);
+                fprintf(fjson, "    \"valmax\": %.17g,\n",dvalue);
+                break;
+            default:
+                return cpl_error_set_message(cpl_func, CPL_ERROR_TYPE_MISMATCH,
+                         "Range parameters not supported for this type");
+                break;
+            }
+            break;
+        /* If an enum, write the list of alternatives as a JSON list.
+           Only integers, doubles and strings are supported */
+        case CPL_PARAMETER_CLASS_ENUM:
+            fprintf(fjson, "    \"partype\": \"enum\",\n");
+            enum_size = cpl_parameter_get_enum_size(param);
+            fprintf(fjson, "    \"valenum\": [");
+            for(ienum = 0; ienum < enum_size; ienum++)
+            {
+                switch (valtype)
+                {
+                case CPL_TYPE_INT:
+                    ivalue = cpl_parameter_get_enum_int(param, ienum);
+                    fprintf(fjson, " %d ",ivalue);
+                    break;
+   
+                case CPL_TYPE_DOUBLE:
+                    dvalue = cpl_parameter_get_enum_double(param, ienum);
+                    fprintf(fjson, " %.17g ",dvalue);
+                    break;
+   
+                case CPL_TYPE_STRING:
+                    svalue = er_json_escape_string(
+                        cpl_parameter_get_enum_string(param, ienum));
+                    fprintf(fjson, " \"%s\" ",svalue);
+                    cpl_free(svalue);
+                    break;
+                default:
+                    return cpl_error_set_message(cpl_func, 
+                             CPL_ERROR_TYPE_MISMATCH,
+                             "Enum parameters not supported for this type");
+                    break;
+                 }
+                 if(ienum != enum_size - 1)
+                    fprintf(fjson, ",");
+            }
+            fprintf(fjson, "],\n");
+            break;
+        default:
+            return cpl_error_set_message(cpl_func, CPL_ERROR_TYPE_MISMATCH,
+                     "Parameter class not supported for cpl_propertylist");
+            break;
+        }
         if(strlen(display_name) > 0)
             fprintf(fjson, "    \"display_name\": \"%s\",\n",display_name);
         if(strlen(description) > 0)
