@@ -239,10 +239,37 @@ cpl_parameter_set_alias (p, CPL_PARAMETER_MODE_ENV,
                          PACKAGE_ENV "_LOG_LEVEL");
 cpl_parameterlist_append (param_list, p);
 
+
   /*
-   *  man-page
+   * no-datamd5 and no-checksum
    */
 
+p = cpl_parameter_new_value (PACKAGE_RESOURCE ".no-datamd5",
+                             CPL_TYPE_BOOL,
+                             "Disables the computation of the MD5 data hash "
+                             "for FITS product files.", PACKAGE_RESOURCE,
+                             FALSE);
+cpl_parameter_set_alias (p, CPL_PARAMETER_MODE_CLI, "no-datamd5");
+cpl_parameter_set_alias (p, CPL_PARAMETER_MODE_ENV,
+                         PACKAGE_ENV "_NO_DATAMD5");
+cpl_parameterlist_append (param_list, p);
+
+
+p = cpl_parameter_new_value (PACKAGE_RESOURCE ".no-checksum",
+                             CPL_TYPE_BOOL,
+                             "Disables the computation of the standard "
+                             "FITS product checksums.", PACKAGE_RESOURCE,
+                             FALSE);
+cpl_parameter_set_alias (p, CPL_PARAMETER_MODE_CLI, "no-checksum");
+cpl_parameter_set_alias (p, CPL_PARAMETER_MODE_ENV,
+                         PACKAGE_ENV "_NO_CHECKSUM");
+cpl_parameterlist_append (param_list, p);
+
+
+/*
+ *  man-page
+ */
+
 p = cpl_parameter_new_value (PACKAGE_RESOURCE ".man-page",
                              CPL_TYPE_BOOL,
                              "Display a manual page for the specified "
@@ -257,9 +284,9 @@ cpl_parameter_set_alias (p, CPL_PARAMETER_MODE_ENV,
                          PACKAGE_ENV "_MAN_PAGE");
 cpl_parameterlist_append (param_list, p);
 
-  /*
-   *  memcheck
-   */
+/*
+ *  memcheck
+ */
 
 p = cpl_parameter_new_value (PACKAGE_RESOURCE ".mem-check",
                              CPL_TYPE_BOOL,
