@@ -63,7 +63,7 @@
  * @param frames        The frames to create the PAF from
  * @param paf_config    The configuration file for PAF creation
  *
- * @returns 0 if successfull, !=0 otherwise
+ * @returns 0 if successful, !=0 otherwise
  *
  * Create a PAF file using the important keywords from the header
  * of the products. The important keywords are specified in the configuration
@@ -95,8 +95,10 @@ int er_create_recipe_pafs
     
     /* Loop into all the products */
     cpl_msg_debug(__func__,"Looping into all the products");
-    frame = cpl_frameset_get_first_const(frames);
-    while (frame != NULL)
+
+    cpl_frameset_iterator *it = cpl_frameset_iterator_new(frames);
+
+    while ((frame = cpl_frameset_iterator_get_const(it)) != NULL)
 	{
 	const char * filename;
 	filename = cpl_frame_get_filename(frame);
@@ -115,6 +117,7 @@ int er_create_recipe_pafs
 	    {
 	        cpl_msg_error(er_func,"Could not get PRO CATG in file %s",
 	                      filename);
+	        cpl_frameset_iterator_delete(it);
 	        er_paf_config_delete(paf_configuration);
 	        cpl_free(arcfile);
 	        paf_err = cpl_error_get_code();
@@ -152,6 +155,7 @@ int er_create_recipe_pafs
 		        cpl_msg_error(er_func,
 		                      "Could not read ARCFILE information from "
 		                      "raw frames");
+	            cpl_frameset_iterator_delete(it);
 		        er_paf_config_delete(paf_configuration);
 		        return CPL_ERROR_DATA_NOT_FOUND;
 		    }
@@ -172,6 +176,7 @@ int er_create_recipe_pafs
 		if(paf_err != CPL_ERROR_NONE)
 		    {
 		    cpl_propertylist_delete(procatg_proplist);
+            cpl_frameset_iterator_delete(it);
 		    er_paf_config_delete(paf_configuration);
 		    cpl_free(arcfile);
 		    return paf_err;
@@ -180,12 +185,16 @@ int er_create_recipe_pafs
 	    cpl_msg_indent_less();
 	    cpl_propertylist_delete(procatg_proplist);
 	    }
-	else
+	else {
             cpl_msg_debug(__func__,"File is not a FITS product %s",
         	    filename);
-	frame = cpl_frameset_get_next_const(frames);
 	}
 
+	cpl_frameset_iterator_advance(it, 1);
+
+	}
+
+    cpl_frameset_iterator_delete(it);
 
     /* Cleanup */
     er_paf_config_delete(paf_configuration);
