@@ -1,4 +1,4 @@
-/* $Id: er_params.c,v 1.64 2013/01/03 17:55:39 cgarcia Exp $
+/* $Id: er_params.c,v 1.64 2013-01-03 17:55:39 cgarcia Exp $
  *
  *   This file is part of the ESO Common Pipeline Library
  *   Copyright (C) 2001-2009 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2013/01/03 17:55:39 $
+ * $Date: 2013-01-03 17:55:39 $
  * $Revision: 1.64 $
- * $Name: esorex-3_10 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1544,45 +1544,6 @@ ER_TRACEX(trace_msg)
 /* Check the error code from parsing the command line */
 if (err != 0) return err;
 
-er_paramutils_tilde_convert (caller_parameter_list);
-
-
-/* If an explicitly specified configuration file is given, then parse that */
-
-if ((p = cpl_parameterlist_find (caller_parameter_list, PACKAGE_RESOURCE ".config")))
-   {
-   const char   *explicit_conf_file;
-
-   /* a config file was explicitly specified - parse it */
-   
-   explicit_conf_file = cpl_parameter_get_string (p);
-   if ((explicit_conf_file != NULL) && (*explicit_conf_file != '\0'))
-      {
-      m = (int) strlen(explicit_conf_file);
-      (void) sprintf(trace_msg,"len of explicit_conf_file = %d, 1st char = %c] \n",
-              m,explicit_conf_file[0]);
-      ER_TRACEX(trace_msg)
-      err2 = params_parse_config_file (caller_parameter_list, explicit_conf_file);
-
-      /* Derek didn't check for this error - why? We do, now. */
-      if (err2 == -5) return err;
-      }
-
-   }
-
-
-/* Parse the command line again, overwriting the explicit config-file */
-
-err = params_parse_config_commandline (caller_parameter_list,
-                             plugin_name, set_of_frames_filenames,
-                             argc, argv, 1);
-
-(void) sprintf(trace_msg,"params_process_configuration(2): err = %d",err);
-ER_TRACEX(trace_msg)
-
-if (err != 0) return err;
-
-
 er_paramutils_tilde_convert (caller_parameter_list);
 
 params_parse_config_postprocess (caller_parameter_list);
