@@ -483,20 +483,21 @@ if (ER_TRACEFLAG)
    ER_TRACEX(trace_msg)
    if (ii > 0)
       {
-      frame = cpl_frameset_get_first(set);
-      while (frame != NULL)
+      cpl_frameset_iterator *it = cpl_frameset_iterator_new(set);
+      while ((frame = cpl_frameset_iterator_get(it)) != NULL)
          {
          gp = cpl_frame_get_filename(frame);
          tp = cpl_frame_get_tag(frame);
          (void) sprintf(trace_msg,"name: %60.60s, %s",gp,tp);
          ER_TRACEX(trace_msg)
    
-         frame = cpl_frameset_get_next(set);
+         cpl_frameset_iterator_advance(it, 1);
          }
+      cpl_frameset_iterator_delete(it);
       }
    }
 
-/* Check if the loading was sucesfully */
+/* Check if the loading was successfully */
 if(!load_sucesfull)
     {
     if(created)
@@ -535,18 +536,29 @@ _upda_products (cpl_frameset *frameset, unsigned int flags)
 
     ER_TRACE(__func__);
 
-#if 0
-    reto = cpl_dfs_update_product_header(frameset);
-#else
+    cpl_size pcount = 0;
+    cpl_frameset_iterator *it = cpl_frameset_iterator_new(frameset);
+
+    const cpl_frame *frame = NULL;
+
+    while ((frame = cpl_frameset_iterator_get_const(it)) != NULL) {
+
+        if (cpl_frame_get_group(frame) == CPL_FRAME_GROUP_PRODUCT) {
+            ++pcount;
+        }
+
+        cpl_frameset_iterator_advance(it, 1);
+
+    }
+
+    cpl_frameset_iterator_delete(it);
+    it = NULL;
+
+    if ((pcount != 0) && (flags != CPL_DFS_SIGNATURE_NONE)) {
+        cpl_msg_info(er_func, "Calculating product checksums");
+    }
 
-#if 0
-    unsigned int _flags = CPL_DFS_SIGNATURE_DATAMD5 | CPL_DFS_SIGNATURE_CHECKSUM;
-    reto = cpl_dfs_sign_products(frameset, _flags);
-#else
     reto = cpl_dfs_sign_products(frameset, flags);
-#endif
-
-#endif
 
     if (reto != CPL_ERROR_NONE)
     {
@@ -700,8 +712,10 @@ _move_products (cpl_frameset * frameset,
     /* Loop through the frameset */
 
     move_err = 0;				/* init possible error from moving files */
-    frame = cpl_frameset_get_first (frameset);
-    while (frame != NULL)
+
+    cpl_frameset_iterator *it = cpl_frameset_iterator_new(frameset);
+
+    while ((frame = cpl_frameset_iterator_get(it)) != NULL)
     {
         if (cpl_frame_get_group (frame) == CPL_FRAME_GROUP_PRODUCT)
         {
@@ -750,6 +764,7 @@ _move_products (cpl_frameset * frameset,
             cpp = cpl_frame_get_filename (frame);
             if (cpp == NULL)
             {
+                cpl_frameset_iterator_delete(it);
                 cpl_msg_error (er_func, "cpl_frame_get_filename failed");
                 move_err = 63;
                 goto report_products;
@@ -836,6 +851,7 @@ _move_products (cpl_frameset * frameset,
             ii = system(command_str);
             if (ii != 0) 
                {
+               cpl_frameset_iterator_delete(it);
                cpl_msg_error(er_func, "Error moving product file '%s'", cpp);
                move_err = 64;
                (void) sprintf(trace_msg, "move command returned: %d",ii);
@@ -854,6 +870,7 @@ _move_products (cpl_frameset * frameset,
                   }
                else
                   {
+                  cpl_frameset_iterator_delete(it);
                   cpl_msg_error (er_func,"Unable to move product file to final "
                            "output location (%s)", output_name);
                   move_err = 61;
@@ -877,6 +894,7 @@ _move_products (cpl_frameset * frameset,
                 ii = system(command_str);
                 if (ii != 0)
                 {                   /* now, product file should be there... */
+                    cpl_frameset_iterator_delete(it);
                     cpl_msg_error (er_func,
                                    "Unable to move product file to final output path (%s)",
                                    output_name);
@@ -894,6 +912,8 @@ _move_products (cpl_frameset * frameset,
             {
                 if (er_fileutils_link (link_dir, output_name) != EXIT_SUCCESS)
                 {
+                    cpl_frameset_iterator_delete(it);
+
                     cpl_msg_error (er_func,
                                    "Unable to create symbolic link for %s in "
                                    "directory %s", output_name, link_dir);
@@ -910,9 +930,11 @@ _move_products (cpl_frameset * frameset,
 
         /* Get the next frame in the list */
 
-        frame = cpl_frameset_get_next (frameset);
+        cpl_frameset_iterator_advance(it, 1);
+
     }                            /* End of (while) loop through all frames in frameset */
 
+    cpl_frameset_iterator_delete(it);
 
     /* Report how many products were created (getting the plural right!) */
 
@@ -1563,18 +1585,23 @@ if (flag_plugin_found != 0)			/*  = TRUE */
           {
                cpl_frameset * output_frames;
                cpl_frame    * frame;
+               cpl_frameset_iterator *it =
+                       cpl_frameset_iterator_new(trecipe->frames);
+
                output_frames = cpl_frameset_new();
-               frame = cpl_frameset_get_first (trecipe->frames);
-               while (frame != NULL)
+
+               while ((frame = cpl_frameset_iterator_get(it)) != NULL)
                {
                    if (cpl_frame_get_group (frame) == CPL_FRAME_GROUP_PRODUCT)
                    {
                        cpl_frameset_insert(output_frames, 
                                            cpl_frame_duplicate(frame));
                    }
-                   frame = cpl_frameset_get_next(trecipe->frames);
+                   cpl_frameset_iterator_advance(it, 1);
                }
                
+               cpl_frameset_iterator_delete(it);
+
                if(strlen(val_products_sof)>5 && 
                        strncmp(val_products_sof + strlen(val_products_sof) - 5,
                                ".json", 5) == 0 )
@@ -1650,8 +1677,9 @@ if ((flag_time_plugin != 0) && (flag_plugin_found != 0))
 
    /* loop again over frameset - now, all tags should be set by the recipe */
 
-   frame = cpl_frameset_get_first (holdme);
-   while (frame != NULL)
+   cpl_frameset_iterator *it = cpl_frameset_iterator_new(holdme);
+
+   while ((frame = cpl_frameset_iterator_get(it)) != NULL)
       {
       if (cpl_frame_get_group (frame) == CPL_FRAME_GROUP_RAW)
          {			 /* Get the filename as specified by the frame */
@@ -1665,9 +1693,11 @@ if ((flag_time_plugin != 0) && (flag_plugin_found != 0))
             infile_count ++;
             }
          }
-      frame = cpl_frameset_get_next (holdme);
+      cpl_frameset_iterator_advance(it, 1);
       }
 
+   cpl_frameset_iterator_delete(it);
+
    if ((plugin_time_end > 0.0) && (fsz > 0.0))
       {
       cpl_msg_info (er_func, "Recipe operation(s) took %14.3g seconds to complete.",
