@@ -35,8 +35,6 @@
 
 #include <er_stringarray.h>
 
-#endif	/* ER_PLUGIN_H */
-
 
 CPL_BEGIN_DECLS
 
@@ -80,28 +78,6 @@ extern cpl_frameset *er_frameset_load
 )
 ;
 
-extern int upda_products 
-(
-  cpl_frameset * frameset
-)
-;
-
-extern int move_products 
-(
-  cpl_frameset * frameset,
-  char * output_directory,
-  char * output_prefix,
-  char * link_directory,
-  int flag_noprefix, 
-  int flag_nolink, 
-  int flag_readonly
-)
-;
-
-
 CPL_END_DECLS
 
-
-
-/* End of file */
-
+#endif  /* ER_PLUGIN_H */
