@@ -66,12 +66,14 @@ static void esorex_json_parameterlist(void)
     cpl_parameter     * par2;
     cpl_parameter     * par3;
     cpl_parameter     * par4;
+    cpl_parameter     * par5;
+    cpl_parameter     * par6;
     cpl_parameterlist * parlist;
     
     /* Export a parameterlist to a JSON file */
 
     par1 = cpl_parameter_new_value("recipe.par1", CPL_TYPE_DOUBLE,
-                                   "Description 1","recipe", 10.0);
+                                   "Description 1","rec1", 10.0);
     
     cpl_test_nonnull( par1 );
 
@@ -88,6 +90,13 @@ static void esorex_json_parameterlist(void)
     par4 = cpl_parameter_new_value("recipe.par4", CPL_TYPE_INT,
                                    "Escaped chars \" / \f \n \r \t \\","recipe", -10);
     
+    par5 = cpl_parameter_new_enum("recipe.par5", CPL_TYPE_STRING,
+                                  "Description 5","recipe", "Str1", 
+                                  3,"Str1", "Str2", "Str3");
+    
+    par6 = cpl_parameter_new_range("recipe.par6", CPL_TYPE_INT,
+                                  "Description 6","recipe", 0, -1, 1);
+
     cpl_test_nonnull( par4 );
 
     parlist = cpl_parameterlist_new();
@@ -109,7 +118,9 @@ static void esorex_json_parameterlist(void)
         const char * expected_json="[\n"
                 "  {\n"
                 "    \"name\": \"recipe.par1\",\n"
-                "    \"value\": \"10\",\n"
+                "    \"value\": 10,\n"
+                "    \"valtype\": \"double\",\n"
+                "    \"partype\": \"value\",\n"
                 "    \"display_name\": \"recipe.par1\",\n"
                 "    \"description\": \"Description 1\",\n"
                 "    \"recipe\": \"recipe_name\"\n"
@@ -146,7 +157,9 @@ static void esorex_json_parameterlist(void)
         const char * expected_json="[\n"
                 "  {\n"
                 "    \"name\": \"recipe.par1\",\n"
-                "    \"value\": \"10\",\n"
+                "    \"value\": 10,\n"
+                "    \"valtype\": \"double\",\n"
+                "    \"partype\": \"value\",\n"
                 "    \"display_name\": \"recipe.par1\",\n"
                 "    \"description\": \"Description 1\"\n"
                 "  }\n"
@@ -174,6 +187,8 @@ static void esorex_json_parameterlist(void)
     cpl_parameterlist_append(parlist, par2);
     cpl_parameterlist_append(parlist, par3);
     cpl_parameterlist_append(parlist, par4);
+    cpl_parameterlist_append(parlist, par5);
+    cpl_parameterlist_append(parlist, par6);
     
     cpl_test_error(CPL_ERROR_NONE);
             
@@ -190,7 +205,9 @@ static void esorex_json_parameterlist(void)
         const char * expected_json="[\n"
                 "  {\n"
                 "    \"name\": \"recipe.par1\",\n"
-                "    \"value\": \"10\",\n"
+                "    \"value\": 10,\n"
+                "    \"valtype\": \"double\",\n"
+                "    \"partype\": \"value\",\n"
                 "    \"display_name\": \"recipe.par1\",\n"
                 "    \"description\": \"Description 1\",\n"
                 "    \"recipe\": \"recipe_name\"\n"
@@ -198,6 +215,8 @@ static void esorex_json_parameterlist(void)
                 "  {\n"
                 "    \"name\": \"recipe.par2\",\n"
                 "    \"value\": \"String\",\n"
+                "    \"valtype\": \"string\",\n"
+                "    \"partype\": \"value\",\n"
                 "    \"display_name\": \"recipe.par2\",\n"
                 "    \"description\": \"Description 2\",\n"
                 "    \"recipe\": \"recipe_name\"\n"
@@ -205,16 +224,41 @@ static void esorex_json_parameterlist(void)
                 "  {\n"
                 "    \"name\": \"recipe.par3\",\n"
                 "    \"value\": true,\n"
+                "    \"valtype\": \"bool\",\n"
+                "    \"partype\": \"value\",\n"
                 "    \"display_name\": \"recipe.par3\",\n"
                 "    \"description\": \"Description 3\",\n"
                 "    \"recipe\": \"recipe_name\"\n"
                 "  },\n"
                 "  {\n"
                 "    \"name\": \"recipe.par4\",\n"
-                "    \"value\": \"-10\",\n"
+                "    \"value\": -10,\n"
+                "    \"valtype\": \"int\",\n"
+                "    \"partype\": \"value\",\n"
                 "    \"display_name\": \"recipe.par4\",\n"
                 "    \"description\": \"Escaped chars \\\" \\/ \\f \\n \\r \\t \\\\\",\n"
                 "    \"recipe\": \"recipe_name\"\n"
+                "  },\n"
+                "  {\n"
+                "    \"name\": \"recipe.par5\",\n"
+                "    \"value\": \"Str1\",\n"
+                "    \"valtype\": \"string\",\n"
+                "    \"partype\": \"enum\",\n"
+                "    \"valenum\": [ \"Str1\" , \"Str2\" , \"Str3\" ],\n"
+                "    \"display_name\": \"recipe.par5\",\n"
+                "    \"description\": \"Description 5\",\n"
+                "    \"recipe\": \"recipe_name\"\n"
+                "  },\n"
+                "  {\n"
+                "    \"name\": \"recipe.par6\",\n"
+                "    \"value\": 0,\n"
+                "    \"valtype\": \"int\",\n"
+                "    \"partype\": \"range\",\n"
+                "    \"valmin\": -1,\n"
+                "    \"valmax\": 1,\n"
+                "    \"display_name\": \"recipe.par6\",\n"
+                "    \"description\": \"Description 6\",\n"
+                "    \"recipe\": \"recipe_name\"\n"
                 "  }\n"
                 "]\n\0";
 
@@ -241,6 +285,7 @@ static void esorex_json_parameterlist(void)
                 er_recipe_parameterlist_to_json(parlist, "recipe_name",
                         "/non-existent/path/parlist.json");
         cpl_test_error(CPL_ERROR_FILE_NOT_CREATED);
+        cpl_test_eq(errcode , CPL_ERROR_FILE_NOT_CREATED);
     }
     
     /* Trying with null inputs */
@@ -249,14 +294,17 @@ static void esorex_json_parameterlist(void)
                 er_recipe_parameterlist_to_json(NULL, "recipe_name",
                         "parlist.json");
         cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
+        cpl_test_eq(errcode , CPL_ERROR_ILLEGAL_INPUT);
         
         errcode =  er_recipe_parameterlist_to_json(parlist, NULL,
                          "parlist.json");
         cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
+        cpl_test_eq(errcode , CPL_ERROR_ILLEGAL_INPUT);
 
         errcode =  er_recipe_parameterlist_to_json(parlist, "recipe_name",
                          NULL);
         cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
+        cpl_test_eq(errcode , CPL_ERROR_ILLEGAL_INPUT);
     }
     
     cpl_parameterlist_delete(parlist);
@@ -329,7 +377,7 @@ static void esorex_json_frameset(void)
         cpl_free(whole_file);
     }
 
-    /* Do the same with a list that contains more than 1 parameter */
+    /* Do the same with a list that contains more than 1 frame */
     cpl_frameset_insert(frameset, fset2);
     cpl_frameset_insert(frameset, fset3);
     
@@ -339,7 +387,6 @@ static void esorex_json_frameset(void)
     er_frameset_to_json(frameset, "frameset2.json");
 
     cpl_test_error(CPL_ERROR_NONE);
-
     /* Read the file and compare it with a static version */
     {
         char * whole_file = 0;
@@ -383,6 +430,7 @@ static void esorex_json_frameset(void)
                 er_frameset_to_json(frameset, 
                         "/non-existent/path/frameset.json");
         cpl_test_error(CPL_ERROR_FILE_NOT_CREATED);
+        cpl_test_eq(errcode , CPL_ERROR_FILE_NOT_CREATED);
     }
     
     /* Trying with null inputs */
@@ -390,9 +438,11 @@ static void esorex_json_frameset(void)
         cpl_error_code errcode = 
                 er_frameset_to_json(NULL, "frameset.json");
         cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
+        cpl_test_eq(errcode , CPL_ERROR_ILLEGAL_INPUT);
         
         errcode = er_frameset_to_json(frameset, NULL);
         cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
+        cpl_test_eq(errcode , CPL_ERROR_ILLEGAL_INPUT);
     }
     
     cpl_frameset_delete(frameset);
